==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.server/src/com/openexchange/groupware/ldap/UserReloader.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.ldap;

import java.util.Locale;
import java.util.Map;
import java.util.Set;
import com.openexchange.caching.dynamic.OXObjectFactory;
import com.openexchange.caching.dynamic.Refresher;
import com.openexchange.exception.OXException;

/**
 * This class is used overall behind the User interface and it manages to reload
 * the user object into the cache if the cache invalidated it.
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
final class UserReloader extends Refresher<User> implements User {

    /**
     * For serialization.
     */
    private static final long serialVersionUID = -2424522083743916869L;

    /**
     * Cached delegate.
     */
    private User delegate;

    /**
     * Default constructor.
     * @param factory Factory for loading the object from the database.
     * @param regionName Name of the cache region that stores the object.
     * @throws OXException if initially loading the object fails.
     */
    UserReloader(final OXObjectFactory<User> factory, final String regionName) throws OXException {
        super(factory, regionName, false);
        this.delegate = refresh();
    }

    public UserReloader(final OXObjectFactory<User> factory, final User user, final String regionName) throws OXException {
        super(factory, regionName, false);
        delegate = user;
        cache(user);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean equals(final Object obj) {
        updateDelegate();
        return delegate.equals(obj);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int hashCode() {
        updateDelegate();
        return delegate.hashCode();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return "UserReloader: " + delegate.toString();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getAliases() {
        updateDelegate();
        return delegate.getAliases();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Map<String, Set<String>> getAttributes() {
        updateDelegate();
        return delegate.getAttributes();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int getContactId() {
        return delegate.getContactId();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getDisplayName() {
        updateDelegate();
        return delegate.getDisplayName();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getGivenName() {
        updateDelegate();
        return delegate.getGivenName();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int[] getGroups() {
        updateDelegate();
        return delegate.getGroups();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int getId() {
        return delegate.getId();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getImapLogin() {
        updateDelegate();
        return delegate.getImapLogin();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getImapServer() {
        updateDelegate();
        return delegate.getImapServer();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Locale getLocale() {
        updateDelegate();
        return delegate.getLocale();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getLoginInfo() {
        updateDelegate();
        return delegate.getLoginInfo();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getMail() {
        updateDelegate();
        return delegate.getMail();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getMailDomain() {
        updateDelegate();
        return delegate.getMailDomain();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getPasswordMech() {
        updateDelegate();
        return delegate.getPasswordMech();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getPreferredLanguage() {
        updateDelegate();
        return delegate.getPreferredLanguage();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int getShadowLastChange() {
        updateDelegate();
        return delegate.getShadowLastChange();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getSmtpServer() {
        updateDelegate();
        return delegate.getSmtpServer();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getSurname() {
        updateDelegate();
        return delegate.getSurname();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getTimeZone() {
        updateDelegate();
        return delegate.getTimeZone();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getUserPassword() {
        updateDelegate();
        return delegate.getUserPassword();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isMailEnabled() {
        updateDelegate();
        return delegate.isMailEnabled();
    }

    /**
     * @throws RuntimeException if refreshing fails.
     */
    private void updateDelegate() throws RuntimeException {
        try {
            final User tmp = refresh();
            if (null != tmp) {
                this.delegate = tmp;
            }
        } catch (final OXException e) {
            throw new RuntimeException(e.getMessage(), e);
        }
    }
}

==> open-xchange-core_7.0.2.orig.tar.bz2: open-xchange-core-7.0.2/com.openexchange.server/src/com/openexchange/groupware/ldap/UserReloader.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.ldap;

import java.util.Locale;
import java.util.Map;
import java.util.Set;
import org.apache.commons.logging.Log;
import com.openexchange.caching.dynamic.OXObjectFactory;
import com.openexchange.caching.dynamic.Refresher;
import com.openexchange.exception.OXException;

/**
 * This class is used overall behind the User interface and it manages to reload the user object into the cache if the cache invalidates it.
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
final class UserReloader extends Refresher<User> implements User {

    private static final transient Log LOG = com.openexchange.log.Log.loggerFor(UserReloader.class);

    private static final long serialVersionUID = -2424522083743916869L;

    /**
     * Cached delegate. This must never be <code>null</code>.
     */
    private User delegate;

    /**
     * Default constructor.
     * @param factory Factory for loading the object from the database.
     * @param regionName Name of the cache region that stores the object.
     * @throws OXException if initially loading the object fails.
     */
    UserReloader(final OXObjectFactory<User> factory, final String regionName) throws OXException {
        super(factory, regionName, false);
        this.delegate = refresh();
    }

    public UserReloader(OXObjectFactory<User> factory, User user, String regionName, boolean doCache) throws OXException {
        super(factory, regionName, false);
        delegate = user;
        if (doCache) {
            cache(user);
        }
    }

    @Override
    public boolean equals(final Object obj) {
//        updateDelegate();
        return delegate.equals(obj);
    }

    @Override
    public int hashCode() {
//        updateDelegate();
        return delegate.hashCode();
    }

    @Override
    public String toString() {
        return "UserReloader: " + delegate.toString();
    }

    @Override
    public String[] getAliases() {
//        updateDelegate();
        return delegate.getAliases();
    }

    @Override
    public Map<String, Set<String>> getAttributes() {
//        updateDelegate();
        return delegate.getAttributes();
    }

    @Override
    public int getContactId() {
        return delegate.getContactId();
    }

    @Override
    public String getDisplayName() {
//        updateDelegate();
        return delegate.getDisplayName();
    }

    @Override
    public String getGivenName() {
//        updateDelegate();
        return delegate.getGivenName();
    }

    @Override
    public int[] getGroups() {
//        updateDelegate();
        return delegate.getGroups();
    }

    @Override
    public int getId() {
        return delegate.getId();
    }

    @Override
    public String getImapLogin() {
//        updateDelegate();
        return delegate.getImapLogin();
    }

    @Override
    public String getImapServer() {
//        updateDelegate();
        return delegate.getImapServer();
    }

    @Override
    public Locale getLocale() {
//        updateDelegate();
        return delegate.getLocale();
    }

    @Override
    public String getLoginInfo() {
//        updateDelegate();
        return delegate.getLoginInfo();
    }

    @Override
    public String getMail() {
//        updateDelegate();
        return delegate.getMail();
    }

    @Override
    public String getMailDomain() {
//        updateDelegate();
        return delegate.getMailDomain();
    }

    @Override
    public String getPasswordMech() {
//        updateDelegate();
        return delegate.getPasswordMech();
    }

    @Override
    public String getPreferredLanguage() {
//        updateDelegate();
        return delegate.getPreferredLanguage();
    }

    @Override
    public int getShadowLastChange() {
//        updateDelegate();
        return delegate.getShadowLastChange();
    }

    @Override
    public String getSmtpServer() {
//        updateDelegate();
        return delegate.getSmtpServer();
    }

    @Override
    public String getSurname() {
//        updateDelegate();
        return delegate.getSurname();
    }

    @Override
    public String getTimeZone() {
//        updateDelegate();
        return delegate.getTimeZone();
    }

    @Override
    public String getUserPassword() {
//        updateDelegate();
        return delegate.getUserPassword();
    }

    @Override
    public boolean isMailEnabled() {
//        updateDelegate();
        return delegate.isMailEnabled();
    }

    /**
     * @throws RuntimeException if refreshing fails.
     */
    private void updateDelegate() throws RuntimeException {
        try {
            final User tmp = refresh();
            if (null != tmp) {
                this.delegate = tmp;
            }
        } catch (OXException e) {
            // Refreshing the used object during normal processing of a single request might be risky. This may cause unexpected behavior if
            // some code reads some attribute two times and gets two different values because of a value change meanwhile.
            LOG.warn(e.getMessage(), e);
        }
    }
}
